import commands

def grep(*args):
  path = args[0]
  key_word = args[1]
  return commands.getoutput("grep -rn '%s' %s"%(key_word, path)).split("\n")

def git_grep(*args):
  path = args[0]
  key_word = args[1]
  return commands.getoutput("cd %s;git grep -n '%s'"%(path, key_word)).split("\n")




def parse(result, *args):
  srcs = result.split(":")
  if len(srcs) < 3:
    pass
  else:
    path = srcs.pop(0)
    number = srcs.pop(0)
    row = ':'.join(srcs)
    return {'path': path, 'number': number, 'row': row}



import os

listings = []
home = ""

def init(path):
  global listings
  global home
  listings = []
  home = path

def listing(fun, *args):
  global listings
  listings = fun(*args)
  os.system("cd %s"%(home))
  return listings

def parse(fun, *args):
  global listings
  tmps = listings
  listings = []
  for result in tmps:
    res = fun(result, *args)
    if not res: continue
    listings.append(res)
  return listings

def output(fun, *args):
  global listings
  listings = fun(listings, *args)
  os.system("cd %s"%(home))
  return listings  




from setuptools import setup
from setuptools import find_packages

setup(
    name = "grep-result",
    version = "0.0.2",
    packages=find_packages(),
    author="llby",
    author_email="llby@shingor.net",
    license="MIT",
    classifiers=["Topic :: Utilities"]
)
